@@ -8,7 +8,6 @@ import json
 
 
 class AIHClient:
-    
     """
     AIHClient is the client that authenticates and connects to the APIs for the given environment.
     """
@@ -20,7 +19,7 @@ class AIHClient:
         if AIHClient._instance:
             return AIHClient._instance
         else:
-            raise AIHE.AIHClientException('AIHClient has not been initialiAIHEd yet.')
+            raise AIHE.AIHClientException('AIHClient has not been initialized yet.')
         
     
     
@@ -42,13 +41,13 @@ class AIHClient:
         # Creates the client
         backend = BackendApplicationClient(client_id=self.client_id)
         self.client = OAuth2Session(client=backend)
-        self.update_token()
+        self._update_token()
     
     
     
     
     
-    def is_expired(self):
+    def _is_expired(self):
         """
         Checks if the Bearer token for the OAuth2 connection is expired
         """
@@ -59,7 +58,7 @@ class AIHClient:
     
     
     
-    def update_token(self):
+    def _update_token(self):
         """
         Gets a new Bearer token.
         Raises Exceptions if the specified environment or client credentials are wrong.
@@ -79,7 +78,7 @@ class AIHClient:
             
             
             
-    def get(self, api:str, endpoint:str, parameters:dict={}):
+    def _get(self, api:str, endpoint:str, parameters:dict={}):
         """
         Sends a HTTPS GET request for the given endpoint.
         Raises an error if HTTPS error occurs.
@@ -91,8 +90,8 @@ class AIHClient:
         OUT: response (json) - A json object for the response
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         if parameters:
             params = '&'.join([f'{k}={v}' for k,v in parameters.items()])
@@ -109,7 +108,7 @@ class AIHClient:
         
 
             
-    def put(self, api:str, endpoint:str, data:dict):
+    def _put(self, api:str, endpoint:str, data:dict):
         """
         Sends a HTTPS PUT request for the given endpoint.
         Raises an error if HTTPS error occurs.
@@ -119,8 +118,8 @@ class AIHClient:
             data (dict)    - The data it should send in the body. It gets converted to json.
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
         headers = {"Content-Type": "application/json"}
@@ -132,7 +131,7 @@ class AIHClient:
         
         
         
-    def post(self, api:str, endpoint:str, data:dict):
+    def _post(self, api:str, endpoint:str, data:dict):
         """
         Sends a HTTPS POST request for the given endpoint.
         Raises an error if HTTPS error occurs.
@@ -144,8 +143,8 @@ class AIHClient:
         OUT: (json)        - The response from the server in a json object
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
         headers = {"Content-Type": "application/json"}
@@ -160,7 +159,7 @@ class AIHClient:
             raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}')
             
             
-    def delete(self, api:str, endpoint:str, id:str):
+    def _delete(self, api:str, endpoint:str, id:str):
         """
         Sends a HTTPS DELETE request for the given endpoint.
         Raises an error if HTTPS error occurs.
@@ -169,8 +168,8 @@ class AIHClient:
             endpoint (str) - Defines the endpoint send a GET request to.
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}/{id}'        
         response = self.client.delete(url)
@@ -179,7 +178,7 @@ class AIHClient:
             raise AIHE.AIHClientException(f'DELETE request failed: {response.status_code}\n{response.text}')
         
             
-    def download_file(self, file_id:str):
+    def _download_file(self, file_id:str):
         """
         download_file downloads the file from DataUpload API.
         
@@ -188,8 +187,8 @@ class AIHClient:
         OUT: (content) - The response content.
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         url = f'https://{self.environment}-du-we-api.azurewebsites.net/files/download/{file_id}'
         response = self.client.get(url)
@@ -197,7 +196,7 @@ class AIHClient:
         return response.content
 
         
-    def upload_file(self, datatype_id:str, file, name:str):
+    def _upload_file(self, datatype_id:str, file, name:str):
         """
         upload_file uploads a file for a DataType to the DataUpload API.
 
@@ -208,8 +207,8 @@ class AIHClient:
         OUT: (json) - The json response
         """
 
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         fileextension = name.split('.')[-1]
         url = f'https://{self.environment}-du-we-api.azurewebsites.net/Files'
@@ -224,7 +223,7 @@ class AIHClient:
         return response.json()
 
 
-    def download_media(self, container:str, name:str):
+    def _download_media(self, container:str, name:str):
         """
         To get download a file from the media objects.
         IN: container (str) - To specify the type of file to donwload e.g. image
@@ -232,8 +231,8 @@ class AIHClient:
             
         OUT: the content of the downloaded file
         """
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/multimedia/{container}/{name}'        
         response = self.client.get(url)
@@ -242,7 +241,7 @@ class AIHClient:
 
     
 
-    def upload_media(self, container, file, name):
+    def _upload_media(self, container, file, name):
         """
         upload_file uploads a file to a data type.
 
@@ -253,8 +252,8 @@ class AIHClient:
         OUT: (json) - The json response
         """
         
-        if(self.is_expired()):
-            self.update_token()
+        if(self._is_expired()):
+            self._update_token()
         
         
         url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/media'
